@@ -1,10 +1,13 @@
 package aws
 
-import "github.com/snyk/driftctl/pkg/resource"
+import (
+	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
+)
 
 const AwsApiGatewayV2MappingResourceType = "aws_apigatewayv2_api_mapping"
 
-func initAwsApiGatewayV2MappingMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+func initAwsApiGatewayV2MappingMetaData(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
 	resourceSchemaRepository.SetHumanReadableAttributesFunc(
 		AwsApiGatewayV2MappingResourceType,
 		func(res *resource.Resource) map[string]string {
