@@ -1,12 +1,13 @@
 package azurerm
 
 import (
-	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/enumeration/resource"
+	dctlresource "github.com/snyk/driftctl/pkg/resource"
 )
 
 const AzureImageResourceType = "azurerm_image"
 
-func initAzureImageMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+func initAzureImageMetaData(resourceSchemaRepository dctlresource.SchemaRepositoryInterface) {
 	resourceSchemaRepository.SetHumanReadableAttributesFunc(AzureImageResourceType, func(res *resource.Resource) map[string]string {
 		attrs := make(map[string]string)
 
