@@ -1,22 +1,23 @@
-package resource
+package resource_test
 
 import (
 	"github.com/hashicorp/terraform/providers"
-	"github.com/snyk/driftctl/enumeration/resource"
-	"github.com/snyk/driftctl/test/schemas"
+	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource/schemas"
+	testschemas "github.com/snyk/driftctl/test/schemas"
 )
 
 func InitFakeSchemaRepository(provider, version string) resource.SchemaRepositoryInterface {
-	repo := resource.NewSchemaRepository()
+	repo := schemas.NewSchemaRepository()
 	schema := make(map[string]providers.Schema)
 	if provider != "" {
-		s, err := schemas.ReadTestSchema(provider, version)
+		s, err := testschemas.ReadTestSchema(provider, version)
 		if err != nil {
 			// TODO HANDLER ERROR PROPERLY
 			panic(err)
 		}
 		schema = s
 	}
-	_ = repo.Init("Fake", "1.0.0", schema)
+	_ = repo.Init(provider, version, schema)
 	return repo
 }
